/**
 * @description editor interface
 * @author wangfupeng
 */
import { Editor, Location, Node, Ancestor, Element } from 'slate';
import ee from 'event-emitter';
import { IEditorConfig, AlertType, ISingleMenuConfig } from '../config/interface';
import { IPositionStyle } from '../menus/interface';
export declare type ElementWithId = Element & {
    id: string;
};
/**
 * 扩展 slate Editor 接口
 */
export interface IDomEditor extends Editor {
    insertData: (data: DataTransfer) => void;
    setFragmentData: (data: DataTransfer) => void;
    getConfig: () => IEditorConfig;
    getMenuConfig: (menuKey: string) => ISingleMenuConfig;
    getAllMenuKeys: () => string[];
    alert: (info: string, type: AlertType) => void;
    handleTab: () => void;
    getHtml: (opt?: {
        withFormat?: boolean;
        containerClassName?: string;
    }) => string;
    getText: () => string;
    getSelectionText: () => string;
    getElemsByTypePrefix: (typePrefix: string) => ElementWithId[];
    getParentNode: (node: Node) => Ancestor | null;
    isEmpty: () => boolean;
    id: string;
    isDestroyed: boolean;
    isFullScreen: boolean;
    focus: () => void;
    isFocused: () => boolean;
    blur: () => void;
    updateView: () => void;
    destroy: () => void;
    scrollToElem: (id: string) => void;
    showProgressBar: (progress: number) => void;
    hidePanelOrModal: () => void;
    enable: () => void;
    disable: () => void;
    isDisabled: () => boolean;
    toDOMNode: (node: Node) => HTMLElement;
    fullScreen: () => void;
    unFullScreen: () => void;
    select: (at: Location) => void;
    deselect: () => void;
    restoreSelection: () => void;
    getSelectionPosition: () => Partial<IPositionStyle>;
    getNodePosition: (node: Node) => Partial<IPositionStyle>;
    on: (type: string, listener: ee.EventListener) => void;
    off: (type: string, listener: ee.EventListener) => void;
    once: (type: string, listener: ee.EventListener) => void;
    emit: (type: string) => void;
    undo?: () => void;
    redo?: () => void;
}
